import pandas as pd
import sys
import numpy as np
     
def delete_outliers(data):
    try:
        data = pd.read_csv(sys.argv[1])

        for i in data.columns:
            sum = 0
            for t in data[i].values :
                if(not np.isnan(t)):
                    sum = sum + t
            sum = sum/len(data[i].values)
            for j,k in enumerate(data[i].values):
                if np.isnan(k) :
                    data[i][j] = sum
        return data
    except:
        print("Make sure you don't have any categorical data")   




def main():
    if(len(sys.argv)<2):
        print("Usage:-  python test.py Data.csv")
        sys.exit(0)
    filename = sys.argv[1]
    try:
        data = pd.read_csv(filename)
    except OSError:
        print('cannot open', filename)
        sys.exit(0)
        
    data = delete_outliers(data)

    try:
        data.to_csv("out.csv",index=False)   
    except OSError:
        print('cannot open', filename)
        sys.exit(0)
        
if __name__=="__main__":
    main()


from distutils.core import setup
setup(
  name = 'missingval_101703353',         # How you named your package folder (MyLib)
  packages = ['missingval_101703353'],   # Chose the same as "name"
  version = '1.0.1',      # Start with a small number and increase it with every change you make
  license='MIT', 
  entry_points ={ 
    'console_scripts': [ 
        'missingval = missingval_101703353.missingval:main'
    ] 
  }, 
  description = 'Replace missing(nan) values with mean',   # Give a short description about your library
  author = 'Mukul Verma',                   # Type in your name
  author_email = 'mverma1_be17@thapar.edu',      # Type in your E-Mail
  keywords = ['nan removal'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'pandas',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.6',
    
  ],
)

